@@ -48,7 +48,7 @@ class BaseLog:
         for level in self.log_levels:
             handler_dict[level] = dict()
             handler_dict[level]['class'] = 'logging.handlers.TimedRotatingFileHandler'
-            handler_dict[level]['level'] = level.upper()
+            handler_dict[level]['level'] = level.upper() if level != 'trace' else 'NOTSET'
             if level == 'info':
                 file_name = self.journal_log_name
             elif level == 'trace':
@@ -67,7 +67,10 @@ class BaseLog:
         loggers_dict[self.journal_log_name]['handlers'] = ['info']
         loggers_dict[self.job_log_name]['handlers'] = ['trace']
         for logger in loggers_dict.keys():
-            loggers_dict[logger]['level'] = 'DEBUG'
+            if logger == self.job_log_name:
+                loggers_dict[logger]['level'] = 'NOTSET'
+            else:
+                loggers_dict[logger]['level'] = 'DEBUG'
             loggers_dict[logger]['propagate'] = False
         config_dict['handlers'] = handler_dict
         config_dict['loggers'] = loggers_dict
@@ -224,7 +227,8 @@ class BaseLog:
                 raise ValueError('传入参数必须为字典')
         except Exception as e:
             self.error(str(e))
-10
+
+
 
 
 
